"""No-op command implementation."""

from promptosaurus.ui.commands.command import Command
from promptosaurus.ui.commands.result import CommandResult
from promptosaurus.ui.domain.context import PipelineContext


class NoOpCommand(Command):
    """No-op command for unknown inputs."""

    def execute(self, context: PipelineContext) -> CommandResult:
        """Execute no-op - continue pipeline without changes."""
        return CommandResult(continue_pipeline=True)
