"""Slow tests for promptosaurus - placeholder for future tests."""

import pytest


@pytest.mark.slow
@pytest.mark.placeholder
def test_slow_placeholder():
    """Placeholder slow test."""
    # TODO: Add slow tests when we have:
    # - Performance benchmarks
    # - Large file processing tests
    # - Stress tests
    pass
