"""Security tests for promptosaurus - placeholder for future tests."""

import pytest


@pytest.mark.security
@pytest.mark.placeholder
def test_integration_placeholder():
    """Placeholder security test."""
    # TODO: Add integration tests when we have:
    pass
